about summary refs log tree commit diff
path: root/buildtools
diff options
context:
space:
mode:
Diffstat (limited to 'buildtools')
-rwxr-xr-xbuildtools/configure.pl12
1 files changed, 6 insertions, 6 deletions
diff --git a/buildtools/configure.pl b/buildtools/configure.pl
index aa94a6bb..42cdc9a2 100755
--- a/buildtools/configure.pl
+++ b/buildtools/configure.pl
@@ -2489,14 +2489,14 @@ if ($platform eq "GNU") {
     push(@config_mk, "CC = cc -no-cpp-precomp\n");
     push(@config_mk, gnuCflags('cc'));
     push(@config_mk, 'CFLAGS_SHLIB = -fno-common', "\n");
     # -D_DARWIN_SOURCE is a hack.  We've seen build fail on MacOS because the
     # C library erroneously neglects to include 'sprintf' and 'vasprintf' in
     # <stdio.h> under the conditions under which Netpbm includes it.
     # -D_DARWIN_SOURCE makes it include them.  *_SOURCE macros are supposed to
     # be defined in the source code to which they apply, but since this is
     # just a hack, we prefer to do it with a compiler option and leave the
     # source code unsullied.
-    push(@config_mk, "CFLAGS += -D_DARWIN_SOURCE\n");
+    push(@config_mk, "CFLAGS += -D_DARWIN_C_SOURCE\n");
 
     my $installNameOpt;
     if ($netpbmlib_runtime_path eq '') {
@@ -2489,14 +2489,14 @@ if ($platform eq "GNU") {
     push(@config_mk, gnuCflags('cc'));
     push(@config_mk, 'CFLAGS_SHLIB = -fno-common', "\n");
-    # -D_DARWIN_SOURCE is a hack.  We've seen build fail on MacOS because the
-    # C library erroneously neglects to include 'sprintf' and 'vasprintf' in
-    # <stdio.h> under the conditions under which Netpbm includes it.
-    # -D_DARWIN_SOURCE makes it include them.  *_SOURCE macros are supposed to
-    # be defined in the source code to which they apply, but since this is
+    # -D_DARWIN_C_SOURCE is a hack.  We've seen build fail on MacOS because
+    # the C library erroneously neglects to include 'sprintf' and 'vasprintf'
+    # in <stdio.h> under the conditions under which Netpbm includes it.
+    # -D_DARWIN_C_SOURCE makes it include them.  *_SOURCE macros are supposed
+    # to be defined in the source code to which they apply, but since this is
     # just a hack, we prefer to do it with a compiler option and leave the
     # source code unsullied.